==> gatsby-core-theme-31.0.0.tgz: package/src/components/molecules/newsletter/form/index.js <==
/* eslint-disable no-unused-expressions */

import React, { useState, useEffect, useContext } from 'react';
import PropTypes from 'prop-types';
import { Context } from 'gatsby-core-theme/src/context/MainProvider';
import { translate, getUrl } from 'gatsby-core-theme/src/helpers/getters';
import Form from '../../../organisms/form';
import { newsLetterForm } from '../../../../constants/forms';

const NewsletterForm = ({
  handleApi,
  redirectUrl,
  submitText = 'Submit',
  market,
  setErr,
  path,
}) => {
  const [ip, setIP] = useState('');
  const [error, setError] = useState(false);
  const { translations } = useContext(Context) || {};

  const getData = async () => {
    await fetch('https://geolocation-db.com/json/', {
      method: 'GET',
    })
      .then((response) => response.json())
      .then((data) => setIP(data.IPv4))
      .catch((err) => {
        // console.log(`Error ${err}`);
      });
  };

  useEffect(() => {
    getData();
  }, []);

  const bacomApi = async (name, email, phomeNumber) => {
    // eslint-disable-next-line no-bitwise
    const timestamp = (Date.now() / 1000) | 0;
    const refUrl = process.env.BACOM_REF_URL;
    const validatePhoneNr = typeof phomeNumber === 'undefined';
    const refName = getUrl(path)?.replace('https://', '') || process.env.BACOM_REF_NAME;

    await fetch(
      `https://bacom.dk/subscribe/gig/?firstname=${name}&user_ip=${ip}&ref_name=${refName}&ref_url=${refUrl}&timestamp=${timestamp}&country=${
        process.env.COUNTRY
      }&email=${email}${!validatePhoneNr ? `&phone_number=${phomeNumber}` : ''}`,
      {
        method: 'GET',
        headers: {
          'Content-Type': 'application/json',
          Accept: 'application/json',
        },
      }
    ).then((res) =>
      res.text().then((text) => {
        text === 'OK' ? (window.location.href = redirectUrl) : setError(true);
      })
    );
  };

  const handelSubmit = (e) =>
    handleApi
      ? handleApi(e?.name?.value, e?.email?.value, e?.phomeNumber?.value, ip)
      : bacomApi(e?.name?.value, e?.email?.value, e?.phomeNumber?.value);

  if (error || setErr)
    return (
      <span>
        {translate(
          translations,
          'fail_error_newsletter',
          'Something went wrong. Please try again later!'
        )}{' '}
      </span>
    );

  return (
    <Form
      formOptions={newsLetterForm[market] || newsLetterForm.default}
      successMessage={translate(translations, 'newsletter_form_thanks', '')}
      failMessage={translate(
        translations,
        'fail_error_newsletter',
        'Something went wrong. Please try again later!'
      )}
      customeSubmit={handelSubmit}
      customError
      buttonLabel={submitText}
      path={path}
    />
  );
};
NewsletterForm.propTypes = {
  handleApi: PropTypes.func,
  redirectUrl: PropTypes.string,
  submitText: PropTypes.string,
  market: PropTypes.string,
  setErr: PropTypes.bool,
  path: PropTypes.string,
};

export default NewsletterForm;

==> gatsby-core-theme-31.0.2.tgz: package/src/components/molecules/newsletter/form/index.js <==
/* eslint-disable no-unused-expressions */

import React, { useState, useEffect, useContext } from 'react';
import PropTypes from 'prop-types';
import { Context } from 'gatsby-core-theme/src/context/MainProvider';
import { translate, getUrl } from 'gatsby-core-theme/src/helpers/getters';
import Form from '../../../organisms/form';
import { newsLetterForm } from '../../../../constants/forms';

const NewsletterForm = ({
  handleApi,
  redirectUrl,
  submitText = 'Submit',
  market,
  setErr,
  path,
  country,
}) => {
  const [ip, setIP] = useState('');
  const [error, setError] = useState(false);
  const { translations } = useContext(Context) || {};

  const getData = async () => {
    await fetch('https://geolocation-db.com/json/', {
      method: 'GET',
    })
      .then((response) => response.json())
      .then((data) => setIP(data.IPv4))
      .catch((err) => {
        // console.log(`Error ${err}`);
      });
  };

  useEffect(() => {
    getData();
  }, []);

  const bacomApi = async (name, email, phomeNumber) => {
    // eslint-disable-next-line no-bitwise
    const timestamp = (Date.now() / 1000) | 0;
    const refUrl = process.env.BACOM_REF_URL;
    const validatePhoneNr = typeof phomeNumber === 'undefined';
    const refName = getUrl(path)?.replace('https://', '') || process.env.BACOM_REF_NAME;

    await fetch(
      `https://bacom.dk/subscribe/gig/?firstname=${name}&user_ip=${ip}&ref_name=${refName}&ref_url=${refUrl}&timestamp=${timestamp}&country=${country}&email=${email}${
        !validatePhoneNr ? `&phone_number=${phomeNumber}` : ''
      }`,
      {
        method: 'GET',
        headers: {
          'Content-Type': 'application/json',
          Accept: 'application/json',
        },
      }
    ).then((res) =>
      res.text().then((text) => {
        text === 'OK' ? (window.location.href = redirectUrl) : setError(true);
      })
    );
  };

  const handelSubmit = (e) =>
    handleApi
      ? handleApi(e?.name?.value, e?.email?.value, e?.phomeNumber?.value, ip)
      : bacomApi(e?.name?.value, e?.email?.value, e?.phomeNumber?.value);

  if (error || setErr)
    return (
      <span>
        {translate(
          translations,
          'fail_error_newsletter',
          'Something went wrong. Please try again later!'
        )}{' '}
      </span>
    );

  return (
    <Form
      formOptions={newsLetterForm[market] || newsLetterForm.default}
      successMessage={translate(translations, 'newsletter_form_thanks', '')}
      failMessage={translate(
        translations,
        'fail_error_newsletter',
        'Something went wrong. Please try again later!'
      )}
      customeSubmit={handelSubmit}
      customError
      buttonLabel={submitText}
      path={path}
    />
  );
};
NewsletterForm.propTypes = {
  handleApi: PropTypes.func,
  redirectUrl: PropTypes.string,
  submitText: PropTypes.string,
  market: PropTypes.string,
  setErr: PropTypes.bool,
  path: PropTypes.string,
  country: PropTypes.string,
};

export default NewsletterForm;
